"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("./api");
const validation_1 = require("./validation");
function offerCheckoutModelToOrderViewModel(cm) {
    const result = cm.result;
    return {
        allItems: result.allItems,
        address: null,
        adjustments: [],
        amtCharged: result.totalPrice,
        cardNum: cm.creditCardId,
        cardType: '',
        credit: result.accountBalanceUsed,
        discount: result.promoValue,
        date: new Date(),
        isRevealed: true,
        offerSef: cm.offerSef,
        offerTitle: '',
        orderId: result.orderGuid,
        paymentStatus: '',
        promo: JSON.stringify(result.promotionsUsed),
        status: '',
        subtotal: result.subtotal,
        tax: result.taxComputed.orderTaxAmt,
        totalQty: cm.qty,
        xTracking: null,
        unitPrice: cm.result.subtotal / cm.qty,
    };
}
exports.offerCheckoutModelToOrderViewModel = offerCheckoutModelToOrderViewModel;
// never rejects.
function createOrReuseAddressAndPayment(noAuthAddress, noAuthPayment, sessionId) {
    return new Promise((resolve, reject) => {
        const paymentApi = new api_1.PaymentApi();
        if (!noAuthAddress || !noAuthPayment || !sessionId) {
            resolve({ value: null, success: false, message: null });
        }
        const handleError = (error) => {
            resolve({ value: null, success: false, message: JSON.stringify(error) });
        };
        paymentApi.paymentGetAddressAndPayment(sessionId).then((ea) => {
            // see if the payment already exists...
            for (let i = 0; i < ea.value.length; ++i) {
                if (addressEquals(ea.value[i].address, noAuthAddress, false)) {
                    if (equalsApiBillingModelWithAuthnet(ea.value[i].payment, noAuthPayment, false)) {
                        resolve({ value: ea.value[i], success: true, message: null });
                        return;
                    }
                }
            }
            // not found, so try to create it...
            const model = {
                address: noAuthAddress,
                payment: noAuthPayment,
            };
            paymentApi.paymentPostAddressAndPayment(sessionId, model).then((paymentResult) => {
                resolve(paymentResult);
            }, handleError);
        }, handleError);
    });
}
exports.createOrReuseAddressAndPayment = createOrReuseAddressAndPayment;
// never rejects.
function createOrReuseUserAccount(model) {
    return new Promise((resolve) => {
        const api = new api_1.UserApi();
        const errorHandler = (err) => {
            return { value: null, message: JSON.stringify(err), success: false };
        };
        api.userSignup3({ model }).then((signupResult) => {
            console.log('usersignup done', signupResult);
            if ((signupResult.message || '').indexOf('already exists') > -1) {
                // oh maybe we already created the account, try to log in
                api.userSignIn3({ model }).then((loginResult) => resolve(loginResult), errorHandler);
            }
            resolve(signupResult);
        });
    });
}
exports.createOrReuseUserAccount = createOrReuseUserAccount;
function cleanDisplay(name) {
    if (!name || validation_1.isEmpty(name)) {
        return '';
    }
    return name.replace(/\bRose\b/ig, 'Rosé');
}
exports.cleanDisplay = cleanDisplay;
function eq(s1, s2) {
    if (validation_1.isEmpty(s1) && !validation_1.isEmpty(s2)) {
        return false;
    }
    if (validation_1.isEmpty(s2) && !validation_1.isEmpty(s1)) {
        return false;
    }
    if ((s1 || '').toLowerCase().trim() !== (s2 || '').toLowerCase().trim()) {
        return false;
    }
    return true;
}
function addressEquals(a1, a2, checkId) {
    if (checkId && !eq(a1.id, a2.id)) {
        return false;
    }
    if (!eq(a1.firstName, a2.firstName)) {
        return false;
    }
    if (!eq(a1.lastName, a2.lastName)) {
        return false;
    }
    if (!eq(a1.address1, a2.address1)) {
        return false;
    }
    if (!eq(a1.address2, a2.address2)) {
        return false;
    }
    if (!eq(a1.city, a2.city)) {
        return false;
    }
    // if (!eq(a1.isDefault, a2.isDefault)) {
    // 	return false;
    // }
    if (!eq(a1.cplId, a2.cplId)) {
        return false;
    }
    if (!eq(a1.state, a2.state)) {
        return false;
    }
    if (!eq(a1.carrierPreference, a2.carrierPreference)) {
        return false;
    }
    if (!eq(a1.zip, a2.zip)) {
        return false;
    }
    if (!eq(a1.phone, a2.phone)) {
        return false;
    }
    // if (!eq(a1.status, a2.status)) {
    // 	return false;
    // }
    // if (!eq(a1.dateAdded, a2.dateAdded)) {
    // 	return false;
    // }
    return true;
}
function equalsApiBillingModelWithAuthnet(p1, p2, checkId) {
    // if (checkId && !eq(p1.userGuid, p2.userGuid)) {
    // 	return false;
    // }
    // if (!eq(p1.authNetUserProfileId, p2.authNetUserProfileId)) {
    // 	return false;
    // }
    // if (!eq(p1.authNetUserId, p2.authNetUserId)) {
    // 	return false;
    // }
    // if (!eq(p1.authNetPaymentProfileId, p2.authNetPaymentProfileId)) {
    // 	return false;
    // }
    // if (!eq(p1.authNetShippingProfileId, p2.authNetShippingProfileId)) {
    // 	return false;
    // }
    // if (!eq(p1.isDeleted, p2.isDeleted)) {
    // 	return false;
    // }
    if (!eq(p1.billingAddressId, p2.billingAddressId)) {
        return false;
    }
    if (!eq(p1.cvv, p2.cvv)) {
        return false;
    }
    if (!eq(p1.firstName, p2.firstName)) {
        return false;
    }
    if (!eq(p1.lastName, p2.lastName)) {
        return false;
    }
    // if (!eq(p1.dateAdded, p2.dateAdded)) {
    // 	return false;
    // }
    // if (!eq(p1.expiryYear, p2.expiryYear)) {
    // 	return false;
    // }
    // if (!eq(p1.expiryMonth, p2.expiryMonth)) {
    // 	return false;
    // }
    if (!eq(p1.cardNumber, p2.cardNumber)) {
        return false;
    }
    if (checkId && !eq(p1.id, p2.id)) {
        return false;
    }
    // if (!eq(p1.isDefault, p2.isDefault)) {
    // 	return false;
    // }
    // if (!eq(p1.cardType, p2.cardType)) {
    // 	return false;
    // }
    return true;
}
//# sourceMappingURL=checkout-util.js.map