import { ApiBillingModelWithCardNumber, NhAddressModel } from "./api";
export declare type IAddressChangeHandler = (newId: string) => void;
export interface IAddressPickerProps {
    onChange?: IAddressChangeHandler;
    onAdded?: IAddressChangeHandler;
    allowAdd?: boolean;
    inLine?: boolean;
    addresses: AddressState[];
    defaultAddressId?: string;
}
export declare type IPaymentUpdater = (data: PaymentState) => void;
export interface IPaymentPickerProps {
    onChange?: IAddressChangeHandler;
    onAdded?: IAddressChangeHandler;
    allowAdd?: boolean;
    inLine?: boolean;
    initialPayments?: PaymentState[];
    defaultCardId?: string;
}
export interface IPaymentPickerState {
    loading: boolean;
    isAdding: boolean;
    payments: PaymentState[];
    creditCardId: string;
    isSignedIn: boolean;
}
export interface IPaymentProps {
    onChange: IPaymentUpdater;
    accountBalance: number;
    isCompact: boolean;
    disabled: boolean;
    newUser: boolean;
    onClose?: () => void;
    showClose?: boolean;
    invalidFields: any[];
    requiredFields: any[];
    setInvalidFields: (invalidFields: {
        invalidFields: string[];
    }) => void;
    autoFocus: boolean;
}
export declare class PaymentState implements ApiBillingModelWithCardNumber {
    constructor();
    id?: string;
    name?: string;
    cardNumber?: string;
    cardNumberFormatted?: string;
    firstName: string;
    lastName: string;
    expiryDate?: string;
    expiryMonth?: number;
    expiryYear?: number;
    isDefault?: boolean;
    cvv: string;
    password?: string;
    cardType?: string;
}
export declare type IAddressUpdater = (data: AddressState) => void;
export declare type IAddressAndPaymentComplete = (state: AddressAndPaymentState) => any;
export declare type IAddressComplete = (state: AddressState) => any;
export interface IAddressProps {
    onChange: IAddressUpdater;
    disabled: boolean;
    isCompact: boolean;
    validStates: any[];
    invalidFields: any[];
    onError: (error: string) => void;
    requiredFields: any[];
    setInvalidFields: (invalidFieldsObject: any) => void;
    autoFocus: boolean;
}
export interface IAddressAndPaymentProps {
    onComplete?: IAddressAndPaymentComplete;
    canGoBack: boolean;
    onGoBack?: () => void;
    isCompact: boolean;
    newUser?: boolean;
    noSave?: boolean;
    isCloudCheckout?: boolean;
    onSubmit?: (payment: PaymentState) => void;
    defaultCardId?: string;
    blockingOverride: {
        blocking: boolean;
    };
    hasError?: boolean;
    validStates: any[];
    onError?: (error: string) => void;
    children?: any;
}
export interface IAddressFormProps {
    noSave?: boolean;
    onSubmit?: (address: AddressState) => void;
    onError?: (error: string) => void;
    validStates: any[];
    address?: IAddressProps;
    hasError?: boolean;
    blockingOverride?: any;
    onComplete?: IAddressComplete;
    isCompact?: boolean;
    canGoBack?: boolean;
}
export interface IAddressFormState {
    address: AddressState;
    busy: boolean;
    errors: string[];
    requiredFields: Array<{
        name: string;
        validIf: any;
    }>;
    invalidFields: any[];
}
export declare class AddressAndPaymentState {
    constructor(props: any, context: any);
    busy: boolean;
    address: AddressState;
    payment: PaymentState;
    errors: string[];
    creditCardId: string;
    requiredFields: any[];
    invalidFields: any[];
}
export declare class AddressState implements NhAddressModel {
    constructor();
    id?: string;
    firstName?: string;
    lastName?: string;
    address1?: string;
    address2?: string;
    city?: string;
    state?: string;
    zip?: string;
    phone?: string;
    status?: number;
    isDefault?: boolean;
}
