"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const validation_1 = require("./validation");
class PaymentState {
    constructor() {
        this.name = '';
        this.cardNumber = '';
        this.cardNumberFormatted = '';
        this.firstName = '';
        this.lastName = '';
        this.expiryDate = '';
        this.expiryMonth = 0;
        this.expiryYear = 0;
        this.cvv = '';
        this.isDefault = false;
        this.password = '';
    }
}
exports.PaymentState = PaymentState;
class AddressAndPaymentState {
    constructor(props, context) {
        this.busy = false;
        this.address = new AddressState();
        this.payment = new PaymentState();
        this.errors = [];
        this.creditCardId = props.defaultCardId || '';
        this.requiredFields = [
            { name: 'cardNumber', validIf: validation_1.validationTypes.IS_CC_NUMBER },
            { name: 'name', validIf: validation_1.validationTypes.NOT_EMPTY },
            { name: 'cardExp', validIf: validation_1.validationTypes.IS_EXPIRY_DATE },
            { name: 'cardCode', validIf: validation_1.validationTypes.IS_CCV_CODE },
            { name: 'password', validIf: validation_1.validationTypes.NOT_EMPTY },
            { name: 'billFirstName', validIf: validation_1.validationTypes.NOT_EMPTY },
            { name: 'billLastName', validIf: validation_1.validationTypes.NOT_EMPTY },
            { name: 'billStreetAddress1', validIf: validation_1.validationTypes.NOT_EMPTY },
            { name: 'billCity', validIf: validation_1.validationTypes.NOT_EMPTY },
            { name: 'billState', validIf: validation_1.validationTypes.NOT_EMPTY },
            { name: 'billZip', validIf: validation_1.validationTypes.IS_ZIP_CODE },
            { name: 'billPhone', validIf: validation_1.validationTypes.IS_PHONE_NUMBER },
        ];
        this.invalidFields = [];
    }
}
exports.AddressAndPaymentState = AddressAndPaymentState;
class AddressState {
    constructor() {
        if (typeof document !== 'undefined') {
            const firstName = document.cookie.replace(/(?:(?:^|.*;\s*)firstName\s*\=\s*([^;]*).*$)|^.*$/, '$1');
            const lastName = document.cookie.replace(/(?:(?:^|.*;\s*)lastName\s*\=\s*([^;]*).*$)|^.*$/, '$1');
            this.firstName = firstName || '';
            this.lastName = lastName || '';
        }
        else {
            this.firstName = this.lastName = '';
        }
        this.address1 = '';
        this.address2 = '';
        this.city = '';
        this.state = '';
        this.zip = '';
        this.phone = '';
        this.status = null;
        this.isDefault = false;
    }
}
exports.AddressState = AddressState;
//# sourceMappingURL=models.js.map