"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("./api");
const serverless_1 = require("./serverless");
function makeCloudPromise(cloudSef, filters, authToken, search) {
    const definedFilter = typeof filters !== "undefined";
    console.log("cloudPromiseFilters", filters);
    return new Promise((resolve, reject) => {
        new serverless_1.CloudCellarApi()
            .apiCloudCellarGet({
            id: cloudSef,
            authToken,
            search: search || "",
            appellation: definedFilter ? filters.selectedAppellation : "",
            region: definedFilter ? filters.selectedRegion : "",
            varietal: definedFilter ? filters.selectedVarietal : "",
            shipStatus: definedFilter ? filters.selectedShipStatus : "",
        })
            .then((cloudCellarResult) => {
            if (cloudCellarResult.success) {
                const cr = cloudCellarResult.value;
                if (cr !== null) {
                    cr.allItems.items.forEach((item) => (item.qtyInCart = item.qtyInCart || 0));
                    cr.allItems.items = cr.allItems.items.filter((item) => item.item.sku.indexOf("LETTER") !== 0);
                    cr.allItems.items = cr.allItems.items.sort((a, b) => b.wdQty - a.wdQty);
                    resolve(cr);
                }
            }
            else {
                console.error(cloudCellarResult);
            }
        }, (error) => {
            console.error("Failed to load cellar", error, cloudSef);
            reject(error);
        });
    });
}
exports.makeCloudPromise = makeCloudPromise;
function makeOfferPromise(offerSef) {
    return new Promise((resolve, reject) => {
        if (offerSef) {
            new api_1.OfferApi().offerGetDetail({ offerSef }).then((result) => resolve(result), (err) => resolve(null));
        }
        else {
            resolve(null);
        }
    });
}
exports.makeOfferPromise = makeOfferPromise;
function makeOrderPromise(orderId) {
    return new Promise((resolve, reject) => {
        console.log("Loading order " + orderId);
        new api_1.OrderStatusApi().orderStatusGetOrder({ orderId }).then((order) => {
            console.log(order);
            resolve(order);
        }, (error) => {
            console.log(error);
            resolve({
                message: error,
                success: false,
                value: null,
            });
        });
    });
}
exports.makeOrderPromise = makeOrderPromise;
function defaultFilterValues() {
    return {
        selectedAppellation: "",
        selectedRegion: "",
        selectedVarietal: "",
        selectedShipStatus: "",
        wineSef: "",
    };
}
exports.defaultFilterValues = defaultFilterValues;
function makeItemListPromise(filters, pageNumber) {
    const definedFilter = typeof filters !== "undefined";
    const page = parseInt(pageNumber, 10);
    console.log("pagenum: ", pageNumber);
    return new Promise((resolve, reject) => {
        const api = new api_1.ItemDetailApi();
        api
            .itemDetailListItemDetailWithSku({
            search: "",
            skip: (page + 1) * 20,
            take: 20,
            appellation: definedFilter ? filters.selectedAppellation : "",
            region: definedFilter ? filters.selectedRegion : "",
            varietal: definedFilter ? filters.selectedVarietal : "",
        })
            .then((result) => {
            result.value.items = result.value.items.sort((a, b) => b.wdQty - a.wdQty);
            resolve(result.value);
        }, (error) => {
            console.log("Failed to load wine list!", error);
            resolve(null);
        });
    });
}
exports.makeItemListPromise = makeItemListPromise;
//# sourceMappingURL=promises.js.map