"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const validation_1 = require("./validation");
function convertDateToUTC(date) {
    return new Date(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate(), date.getUTCHours(), date.getUTCMinutes(), date.getUTCSeconds());
}
function getTimeRemaining(offerDetail) {
    if (offerDetail && offerDetail.expiryDate) {
        const data = offerDetail;
        const now = convertDateToUTC(new Date()).getTime();
        const expiryDate = new Date(data.expiryDate).getTime(); // already UTC
        if (now > expiryDate) {
            return 'Already Expired!';
        }
        let distance = (expiryDate - now) / 1000;
        const secondsInDay = 86400;
        const days = Math.floor(distance / secondsInDay);
        distance -= days * secondsInDay;
        const secondsInHour = 3600;
        const hours = Math.floor(distance / secondsInHour);
        distance -= hours * secondsInHour;
        const secondsInMinute = 60;
        const minutes = Math.floor(distance / secondsInMinute);
        distance -= minutes * secondsInMinute;
        const seconds = Math.floor(distance);
        return days + 'd: ' + hours + 'h: ' + minutes + 'm: ' + seconds + 's';
    }
    else {
        return '';
    }
}
exports.getTimeRemaining = getTimeRemaining;
;
function toTitleCase(str) {
    return str.replace(/\w\S*/g, (txt) => {
        return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
    });
}
exports.toTitleCase = toTitleCase;
function cleanUrl(i) {
    let val = i || '';
    val = val.toLowerCase().replace(/[^a-z0-9]/g, '-');
    val = val.replace(/-+/g, '-');
    return val;
}
exports.cleanUrl = cleanUrl;
exports.bottleImgSrc = (item) => {
    let url = 'https://undergroundcellar.com/wine-img/';
    if (item.labelImg && !validation_1.isEmpty(item.labelImg[0])) {
        url += item.labelImg[0];
    }
    else if (item.bottleImg && !validation_1.isEmpty(item.bottleImg[0])) {
        url += item.bottleImg[0];
    }
    else {
        url += '5178_Mystery_Wine_4.jpg';
    }
    return url;
};
function getItemsFiltered(order) {
    // todo: use stripLetters function
    return order.allItems.items.filter((item) => (item.item.sku).indexOf('LETTER-') < 0 && (item.item.sku).indexOf('GOLDENTICKET') < 0);
}
exports.getItemsFiltered = getItemsFiltered;
function stripLetters(list) {
    list.items = list.items.filter((wine) => !wine.item.sku.startsWith('LETTER'));
    list.itemCount = list.items.reduce((pre, cur, i) => pre + cur.qty, 0);
    return list;
}
exports.stripLetters = stripLetters;
exports.GeneralGroupings = ['Bordeaux,Bordeaux Blend,Bordeaux Rouge,Cabernet Franc/Cabernet Sauvignon/Merlot/Shiraz,Cabernet Sauvignon/Carmenere,Cabernet Sauvignon/Malbec,Cabernet Sauvignon/Merlot,Cabernet Sauvignon/Merlot/Petit Verdot,Cabernet Sauvignon/Merlot/Syrah,Cabernet Sauvignon/Petite Sirah,Cabernet Sauvignon/Sangiovese,Cabernet Sauvignon/Shiraz,Cabernet Sauvignon/Syrah,Cabernet/Shiraz/Malbec,Carignane/Grenache/Petite Syrah/Syrah,Field Blend,Grenache/Mourvedre/Syrah,Grenache/Shiraz,Grenache/Syrah,GSM,Marselen Red Blend,Mourvedre Syrah Grenache,Proprietary Red,Red Bordeaux,Red Meritage,Red Rhone Blend,Red Table Wine,Red Wine,Red wine,Rhone Blend,Shiraz/Grenache,Syrah Cabernet Sauvignon Merlot,Red Blend,Aglianico,Cabernet Sauvignon,Cabernet Sauvignon Etched Bottle,Cabernet Sauvignon Port,Dolcetto,Gaglioppo,Garnacha,Garnacha/Carinena,Mataro,Mourvedre,Negrette,Petit Verdot,Petite Sirah,Petite Sirah Verdot,Petite Verdot,Pinotage,Pinotage Shiraz,Portuguese Varietals,Sangiovese/Syrah,Shiraz,Shiraz/Viognier,Shiraz‐Cabernet Sauvignon,Syrah,Syrah Blend,Syrah Cabernet,Syrah Viognier,Syrah/Viognier,Tempranillo,Tempranillo Cabernet,Tempranillo Grenache,Touriga Nacional,Verdot,Zinfandel,Zinfandel Port,Zinfandel Shiraz,Zinfandel/Malbec,Agiorgitiko,Aleatico,Bonarda,Charbono,Chianti,Montepulciano,Montepulciano D\'Abruzzo,Nero d\'Avola,Primitivo,Sagrantino,Sangiovese,Sangiovese Barbera Sagrantino,Sangiovese Negroamaro,Barbera,Blaufrankisch,Cabernet Franc,Carignane,Carmenere,Cinsault,Claret,Gamay,Graciano,Grenache,Grenache Noir,Lagrein,Malbec,Malbec Merlot,Merlot,Merlot/Xinomavro,Nebbiolo,Pinot Noir,Pinot Noir Burgundy,Pinot Noir/Syrah,Pinot Noir/Valdiguie,Red Burgundy,Trousseau',
    'Albarino,Amigne,Arneis,Chablis,Fume Blac,Fume Blanc,Grüner Veltliner,Muscat,Orvieto,Picpoul Blanc,Sauv Blanc,Sauvignon Blanc,Sauvignon BlancChardonnay,Sauvignon Gris,Torrontes,Trebbiano Spoletino,Unoaked Chardonnay,Verdejo,Verdelho,Vermentino,Chenin Blanc,Chenin Blanc/Colombard,Gewurztraminer,Johannesburg Riesling,Moscato,Moscato D\'Oro,Moscato Frizzante,Moscato Spumate,Muscato,Riesling,Riesling Traminer,Albana,Blanc,Bukettraube,Catarrato,Chardonnay,Chardonnay/Pinot Grigio,Chardonnay/Pinot Gris,Chardonnay/Semillon,Chardonnay/Viognier,French Colombard,Gargenga/Pinot Grigio,Grenache Blanc,Malvasia Bianca,Marsanne,Marsanne/Viognier,Pinot Blanc,Pinot Grigio,Pinot Gris,Roussanne,Roussanne/Viognier,Sauvignon Blanc/Semillon,Semillon,Semillon/Chardonnay,Viognier,White Bordeaux,White Burgundy,White Rhone Blend,White Blend,White Wine',
    'Blanc de Blancs,Blanc de Noirs,Brut,Brut Cuvee,Brut Rose,Brut Rose of Pinot Noir,Champagne,Chardonnay Champagne,Pinot Noir Brut,Prosecco,Riesling Champagne,Sparkling,Sparkling Brut,Sparkling Chardonnay,Sparkling Cuvee,Sparkling Muscat Canelli,Sparkling Rose,Sparkling Syrah,Sparkling Wine,Rose Champagne',
    'Cabernet Franc/Rose,Cabernet Sauvignon Rosé,Cabernet Sauvignon/Rosé,Dry Rose,Dry Rosé of Pinot Noir,Grenache Rose,Malbec/Rosé,Merlot/Rosé,Pinot Noir Rose,Pinot Rose,Rosato,Rose,Rose of Merlot,Rosé of Pinot Noir,Rose of Syrah,Rosé Table Wine,Rosé/Syrah,Roseto,Sangiovese Rose,Syrah Rosé,Tempranillo Rosé',
    'Botrytised Semillon,Brandy,Dessert Wine,Grappa,Moscatel,Petit Verdot Port,Port,Port/Syrah,Sherry,Syrah Port,Tokaji,Vermouth'];
function IsBottleWhite(varietal) {
    let groupIndex = null;
    exports.GeneralGroupings.forEach((group, index) => {
        const splitGroup = group.split(',');
        const indexMatch = splitGroup.indexOf(varietal);
        if (varietal === splitGroup[indexMatch]) {
            groupIndex = index;
            return;
        }
    });
    return [1, 2, 3].indexOf(groupIndex) !== -1; // 1, 2, 3 are indices of white bottles
}
exports.IsBottleWhite = IsBottleWhite;
//# sourceMappingURL=util.js.map