// This file rewrites:
// 1. api.ts header
// 2. serverless.ts header
// 3. index.ts with non-overlapping exports from api.ts and serverless.ts

const fs = require("fs");

// Load exports for index.js
function writeIndex() {
    let midtier = fs.readFileSync('api.ts', "utf8");
    let serverless = fs.readFileSync('serverless.ts', "utf8");

    const re = (/export (?:interface|class|function) ([a-z0-9_]+)/gi);
    function getExports(str) {
        let result = [];
        match = re.exec(midtier);
        while (match != null) {
            result.push(match[1]);
            match = re.exec(str);
        }
        return result;
    }

    const re2 = (/export namespace ([a-z0-9_]+)/gi);
    function getNamespaceExports(str) {
        let result = [];
        match = re2.exec(midtier);
        while (match != null) {
            result.push(match[1]);
            match = re2.exec(str);
        }
        return result;
    }

    let midtier_exports = {};
    getExports(midtier).forEach((e) => {
        midtier_exports[e] = true;
    });

    let midtier_namespaces = {};
    getNamespaceExports(midtier).forEach((e) => {
        midtier_namespaces[e] = true;
    });

    let serverless_exports = {};
    getExports(serverless).forEach((e) => {
        if (!!midtier_exports[e]) {
            console.log(`Warning: Serverless export ${e} replacing midtier export with same name`);
            delete midtier_exports[e];
        }
        serverless_exports[e] = true;
    });

    let serverless_namespaces = {};
    getNamespaceExports(serverless).forEach((e) => {
        if (!!midtier_namespaces[e]) {
            console.log(`Warning: Serverless namespace ${e} replacing midtier export with same name`);
            delete midtier_namespaces[e];
        }
        serverless_namespaces[e] = true;
    });

    const export_from_api = "\nexport {\n\t" + Object.keys(midtier_exports).join(',\n\t') + ",\n} from './api';\n";

    const export_ns_from_api = "\nexport namespace {\n\t" + Object.keys(midtier_namespaces).join(',\n\t') + ",\n} from './api';\n";

    const export_from_serverless = "\nexport {\n\t" + Object.keys(serverless_exports).join(',\n\t') + ",\n} from './serverless';\n";

    const export_ns_from_serverless = "\nexport namespace {\n\t" + Object.keys(serverless_namespaces).join(',\n\t') + ",\n} from './serverless';\n";

    const marker = "// DO NOT EDIT BELOW HERE - AUTO GENERATED";
    let indexjs = fs.readFileSync("index.ts", "utf8");
    indexjs = indexjs.substr(0, indexjs.indexOf(marker) + marker.length)
        + export_from_api
        + export_from_serverless;
    fs.writeFileSync("index.ts", indexjs);
    console.log('Rewrite index.ts');
}

// Patch api headers
function patch(src, api_path) {
    let header = fs.readFileSync('ci_' + src + '.inc', "utf8");
    let source = fs.readFileSync(src + '.ts', "utf8");
    let search = "export interface FetchArgs";
    let tail = source.substr(source.indexOf(search))
        .replace(/`\/api\//g, "`" + api_path)
        .replace(/return response;/g, 'return response.json();');
    let resFile = header + tail;
    fs.writeFileSync(src + '.ts', resFile);
    console.log('Rewrite ' + src + '.ts');
}

patch('api', '/api/');
patch('serverless', '/azapi/');
writeIndex();
