import {
  ApiResultAttributedItemList,
  ApiResultOrderViewModel,
  AttributedItemList,
  CloudCellarV2,
  ItemDetailApi,
  OfferApi,
  OfferV2Entity,
  OrderStatusApi,
} from "./api";
import { CloudCellarV2ApiResult, CloudCellarApi } from "./serverless";

// UrlToFilter('/k1=v1/k2=v2/k3=v3');

export interface IFilterKeys {
  selectedAppellation: string;
  selectedRegion: string;
  selectedVarietal: string;
  selectedShipStatus?: string;
  wineSef?: string;
}

export function makeCloudPromise(
  cloudSef: string,
  filters: IFilterKeys,
  authToken: string,
  search?: string
) {
  const definedFilter = typeof filters !== "undefined";
  console.log("cloudPromiseFilters", filters);
  return new Promise<CloudCellarV2>((resolve, reject) => {
    new CloudCellarApi()
      .apiCloudCellarGet({
        id: cloudSef,
        authToken,
        search: search || "",
        appellation: definedFilter ? filters.selectedAppellation : "",
        region: definedFilter ? filters.selectedRegion : "",
        varietal: definedFilter ? filters.selectedVarietal : "",
        shipStatus: definedFilter ? filters.selectedShipStatus : "",
      })
      .then(
        (cloudCellarResult: CloudCellarV2ApiResult) => {
          if (cloudCellarResult.success) {
            const cr = cloudCellarResult.value;
            if (cr !== null) {
              cr.allItems.items.forEach(
                (item) => (item.qtyInCart = item.qtyInCart || 0)
              );
              cr.allItems.items = cr.allItems.items.filter(
                (item) => item.item.sku.indexOf("LETTER") !== 0
              );
              cr.allItems.items = cr.allItems.items.sort(
                (a, b) => b.wdQty - a.wdQty
              );
              resolve(cr);
            }
          } else {
            console.error(cloudCellarResult);
          }
        },
        (error) => {
          console.error("Failed to load cellar", error, cloudSef);
          reject(error);
        }
      );
  });
}

export function makeOfferPromise(offerSef: string): Promise<OfferV2Entity> {
  return new Promise((resolve, reject) => {
    if (offerSef) {
      new OfferApi().offerGetDetail({ offerSef }).then(
        (result) => resolve(result),
        (err) => resolve(null)
      );
    } else {
      resolve(null);
    }
  });
}

export function makeOrderPromise(
  orderId: string
): Promise<ApiResultOrderViewModel> {
  return new Promise((resolve, reject) => {
    console.log("Loading order " + orderId);
    new OrderStatusApi().orderStatusGetOrder({ orderId }).then(
      (order) => {
        console.log(order);
        resolve(order);
      },
      (error) => {
        console.log(error);
        resolve({
          message: error,
          success: false,
          value: null,
        });
      }
    );
  });
}

export function defaultFilterValues(): IFilterKeys {
  return {
    selectedAppellation: "",
    selectedRegion: "",
    selectedVarietal: "",
    selectedShipStatus: "",
    wineSef: "",
  };
}

export function makeItemListPromise(
  filters: IFilterKeys,
  pageNumber: string
): Promise<AttributedItemList> {
  const definedFilter = typeof filters !== "undefined";
  const page = parseInt(pageNumber, 10);
  console.log("pagenum: ", pageNumber);
  return new Promise((resolve, reject) => {
    const api = new ItemDetailApi();
    api
      .itemDetailListItemDetailWithSku({
        search: "",
        skip: (page + 1) * 20,
        take: 20,
        appellation: definedFilter ? filters.selectedAppellation : "",
        region: definedFilter ? filters.selectedRegion : "",
        varietal: definedFilter ? filters.selectedVarietal : "",
      })
      .then(
        (result: ApiResultAttributedItemList) => {
          result.value.items = result.value.items.sort(
            (a, b) => b.wdQty - a.wdQty
          );
          resolve(result.value);
        },
        (error) => {
          console.log("Failed to load wine list!", error);
          resolve(null);
        }
      );
  });
}
